---
title: "R Notebook"
output: html_notebook
editor_options:
  chunk_output_type: console
---



    #r warning=TRUE, include=FALSE#
library(tidyverse)
library(haven)
library(ggplot2)
library(labelled)
library(stargazer)
library(skimr)
library(readstata13)

# Resolve conflicts

conflicted::conflict_prefer("select", "dplyr")
conflicted::conflict_prefer("filter", "dplyr")
conflicted::conflict_prefer("count", "dplyr")
conflicted::conflict_prefer("mutate", "dplyr")


rescale_01 <- function(x, min, max){
  (x - min) / (max - min)
}


    #r using black women in politics data#

sis <- read.dta13("~/Sisters in Politics Survey Data (April 2022)/2022-04-18 - Qualtrics - Black Women Politics Clean Data.dta",
                  convert.factors = F, generate.factors = F,encoding = "UTF-8", fromEncoding = NULL, convert.underscore = FALSE,
                  missing.type = FALSE, convert.dates = F, replace.strl = TRUE,add.rownames = FALSE, nonint.factors = TRUE)

#set all names to lowercase
sis <- setNames(sis, tolower(names(sis[1:287])))



    #r recode vars #
table(sis$q33)
sis$news[sis$q33 == 1] <- "Television News"
sis$news[sis$q33 == 2] <- "Newspapers"
sis$news[sis$q33 == 3] <- "Television Talk Shows"
sis$news[sis$q33 == 4] <- "Internet"
sis$news[sis$q33 == 5] <- "Radio"


table(sis$news)



    #r plot where get news#
library(ggthemes)
library(hrbrthemes)
sis_news <- sis %>%
  dplyr::select(news) %>%
  count(news) %>%
mutate(per = round(n/sum(n), digits=2))


#plot
sis_news_plot <- ggplot(data= sis_news, aes(x=reorder(news,per),y=per)) +
  geom_bar(stat= "identity") +
  labs(x = "", y = "%", title = "Black Women's News Source By Media Type", caption = "Black Women in Politics Survey (N= 2,284)\n April 2022")  + theme(legend.position = "bottom") +
   scale_y_continuous(labels = scales::percent) +
 theme_ipsum() +
   geom_text(aes(x = news, y =per, label =sprintf("%0.0f%%", per*100), vjust =0),position=position_stack(vjust=0.5), colour= "White")

sis_news_plot

ggsave(sis_news_plot, width =7, height = 5, filename = "sis_news_plot.jpeg")






    #r top news by education#
#recode education
table(sis$q81)
table(sis$education)

sis$education[sis$q81 == 1] <- "Less Than High School"
sis$education[sis$q81 == 2] <- "Less Than High School"
sis$education[sis$q81 == 3] <- "High School Diploma"
sis$education[sis$q81 == 4] <- "Some College/Associates"
sis$education[sis$q81 == 5] <- "Some College/Associates"
sis$education[sis$q81 == 6] <- "College Degree"
sis$education[sis$q81 == 7] <- "Professional Degree"

#set as factor
sis$education <- as.factor(sis$education)

sis$education <- ordered(sis$education, levels = c("Less Than High School", "High School Diploma", "Some College/Associates", "College Degree", "Professional Degree"))

top_edu_news <- sis %>%
  dplyr::select(news, education, q81)%>%
  group_by(education) %>% count(news) %>%
  mutate(per = round(n/sum(n), digits=2))

top_edu_news
# position=position_dodge()

top_edu_news_plot <- top_edu_news %>%
  ggplot(aes(fill = education, x=reorder(news,per),per)) +
  geom_bar(stat='identity',position=position_dodge(width =0.89)) +
  scale_y_continuous(labels = scales::percent) +
  theme(legend.position="bottom") +
 # coord_flip() +
 theme_ipsum() +
   theme(legend.position = "bottom") + guides(fill = guide_legend(nrow = 2)) +
  labs(x= "  ", y = "   ", title = "Black Women's News Consumption by Education Levels", caption = "Black Women in Politics Survey (N= 2,284)\n April 2022", fill = "")  + geom_text(aes(x = news, y = per, label =sprintf("%0.0f%%", per*100)), size = 2.5,  position=position_dodge(width =0.89), colour = "White", vjust = 2)

top_edu_news_plot

ggsave(top_edu_news_plot, width =9, height = 7, filename = "top_edu_news_plot.jpeg")



    #r GRAPH 1 age x news source#
#recode
table(sis$q5)
sis$generation[sis$q5 >=18 & sis$q5 <=27] <- "Gen Z"
sis$generation[sis$q5 >=28 & sis$q5 <=43] <- "Millenials"
sis$generation[sis$q5 >=44 & sis$q5 <=59] <- "Gen X"
sis$generation[sis$q5 >=60 & sis$q5 <=78] <- "Boomers"
sis$generation[sis$q5 >= 79] <- "Post War"

table(sis$generation)
sis$generation <- as.factor(sis$generation)
sis$generation <- ordered(sis$generation, levels = c("Gen Z",
                                                     "Millenials",
                                                     "Gen X",
                                                     "Boomers",
                                                     "Post War"))

top_age_news <- sis %>%
  dplyr::select(news, generation, q81)%>%
  group_by(generation) %>% count(news) %>%
  mutate(per = round(n/sum(n), digits=2))

top_age_news
# position=position_dodge()

#define color palette
bhm2 <- c("#07060d",
          "#ffe430", "#00bb50","#990000", "#47c9a8")

top_news_gen_plot <- top_age_news %>%
  ggplot(aes(fill = generation, x=reorder(news,per),per)) +
  geom_bar(stat='identity',position=position_dodge(width =0.89)) +
  scale_y_continuous(labels = scales::percent) +
  theme(legend.position="bottom") +
 # coord_flip() +
 theme_ipsum() + scale_fill_manual(values = bhm2) +
   theme(legend.position = "bottom") + guides(fill = guide_legend(nrow = 1)) +
  labs(x= "  ", y = "   ", title = "Black women's news medium by generation", caption = "Black Women in Politics Survey (N= 2,284)\n April 2022", fill = "")  + geom_text(aes(x = news, y = per, label =sprintf("%0.0f%%", per*100)), size = 2.5,  position=position_dodge(width =0.89), colour = "White", vjust = 1.3)

top_news_gen_plot

ggsave(top_news_gen_plot, width =9, height = 7, filename = "[GRAPH 1 revised]top_news_gen_plot.jpeg")



    #r income x posting on social media#
table(sis$q26)
#recode
sis$post_sm[sis$q26 == 2] <- "Do Not Post"
sis$post_sm[sis$q27 == 1] <- "All the time"
sis$post_sm[sis$q27 == 2] <- "Often"
sis$post_sm[sis$q27 == 3] <- "Sometimes"

#set as factor
sis$post_sm <- as.factor(sis$post_sm)

sis$post_sm <- ordered(sis$post_sm, levels = c("All the time", "Often", "Sometimes", "Do Not Post"))

table(sis$post_sm)

sis_sm <- sis %>%
  dplyr::select(post_sm) %>%
  count(post_sm) %>%
mutate(per = round(n/sum(n), digits=2))

#plot
sis_sm_plot <- ggplot(data= sis_sm, aes(x=reorder(post_sm,per),y=per)) +
  geom_bar(stat= "identity") +
  labs(x = "", y = "%", title = "Black Women's Social Media Post Frequency", caption = "Black Women in Politics Survey (N= 2,284)\n April 2022")  + theme(legend.position = "bottom") +
   scale_y_continuous(labels = scales::percent) +
 theme_ipsum() +
   geom_text(aes(x = post_sm, y =per, label =sprintf("%0.0f%%", per*100), vjust =0),position=position_stack(vjust=0.5), colour= "White")

sis_sm_plot

ggsave(sis_sm_plot, width =7, height = 5, filename = "sis_sm_plot.jpeg")

    #r recode income and plot#

table(sis$q82)
sis$income <- NULL

sis$income[sis$q82 == 1] <- "Less than $10k"
sis$income[sis$q82 == 2] <- "$10k - $30k"
sis$income[sis$q82 == 3] <- "$10k - $30k"
sis$income[sis$q82 == 4 | sis$q82 == 5] <- "$30k - $50k"
sis$income[sis$q82 == 6 | sis$q82 == 7] <- "$50k - $70k"
sis$income[sis$q82 == 8 | sis$q82 == 9 | sis$q82 == 10] <- "$70k - $100k"
sis$income[sis$q82 >= 11] <- "More than $100k"

table(sis$income)

sis$income <- as.factor(sis$income)

sis$income <- ordered(sis$income, levels = c("Less than $10k",  "$10k - $30k", "$30k - $50k", "$50k - $70k", "$70k - $100k", "More than $100k"))

top_inc_post <- sis %>%
  dplyr::select(post_sm, income, q81)%>%
  group_by(income) %>% count(post_sm) %>%
  mutate(per = round(n/sum(n), digits=2)) %>%
  print(n=24)

top_inc_post
# position=position_dodge()

top_inc_post_plot <- top_inc_post %>%
  ggplot(aes(fill = income, x=reorder(post_sm,per),per)) +
  geom_bar(stat='identity',position=position_dodge(width =0.89)) +
  scale_y_continuous(labels = scales::percent) +
  theme(legend.position="bottom") +
 # coord_flip() +
 theme_ipsum() +
   theme(legend.position = "bottom") + guides(fill = guide_legend(nrow = 2)) +
  labs(x= "  ", y = "   ", title = "Black Women's Social Media Engagement by Income Levels", caption = "Black Women in Politics Survey (N= 2,284)\n April 2022", fill = "")  + geom_text(aes(x = post_sm, y = per, label =sprintf("%0.0f%%", per*100)), size = 2.5,  position=position_dodge(width =0.89), colour = "White", vjust = 2)

top_inc_post_plot

ggsave(top_inc_post_plot, width =9, height = 7, filename = "top_inc_post_plot.jpeg")



    #r what platforms are black women posting#
#of the 613 Black women that post political messages on social media
class(sis$q28_1)
table(sis$post_fb)


# RENAME ITEMS
sis$post_fb <- ifelse(!is.na(sis$q28_1),1,0)

sis$post_twitter <-ifelse(!is.na(sis$q28_2),1, 0)
sis$post_ig <- ifelse(!is.na(sis$q28_3), 1, 0)
sis$post_tiktok <-ifelse(!is.na(sis$q28_4 ),1, 0)
sis$post_snap <- ifelse(!is.na(sis$q28_5), 1, 0)
sis$post_medium <-ifelse(!is.na(sis$q28_6 ),1, 0)
sis$post_other <- ifelse(!is.na(sis$q28_7), 1, 0)

table(sis$post_other)

post_platform<- sis %>%
  dplyr::select(starts_with("post_")) %>%
  filter(post_sm != "Do Not Post") %>%
  dplyr::summarise(post_fb = mean(post_fb == 1, na.rm=T),
                   post_twitter = mean(post_twitter == 1, na.rm=T),
                   post_ig = mean(post_ig == 1, na.rm =T),
                   post_tiktok = mean(post_tiktok == 1, na.rm=T),
                   post_snap = mean(post_snap == 1, na.rm=T),
                   post_medium = mean(post_medium == 1, na.rm=T),
                   post_other = mean(post_other == 1, na.rm=T)) %>%
  gather(q,r,1:7) %>%
  mutate(r = round(r, digits=2))

#rename items for plot
post_platform
post_platform$q[post_platform$q == "post_fb"] <- "Facebook"
post_platform$q[post_platform$q == "post_twitter"] <- "Twitter"
post_platform$q[post_platform$q == "post_ig"] <- "Instagram"
post_platform$q[post_platform$q == "post_tiktok"] <- "Tik Tok"
post_platform$q[post_platform$q == "post_snap"] <- "Snapchat"
post_platform$q[post_platform$q == "post_medium"] <- "Medium"
post_platform$q[post_platform$q == "post_other"] <- "Another Platform"


post_platform_plot <- post_platform %>%
  ggplot(aes(x=reorder(q,r),r))  +
  geom_bar(stat='identity',position=position_dodge(width =0.89)) +
  scale_y_continuous(labels = scales::percent) +
 theme_ipsum() +
   theme(legend.position = "bottom") + guides(fill = guide_legend(nrow = 2)) +
  labs(x= "  ", y = "   ", title = "Black Women's Social Media Engagement by Platform", caption = "Black Women in Politics Survey (n=613)\n April 2022", fill = "")  + geom_text(aes(x = q, y = r, label =sprintf("%0.0f%%", r*100)), size = 2.5,  position=position_dodge(width =0.89), colour = "White", vjust = 2)



post_platform_plot


ggsave(post_platform_plot, width =9, height = 7, filename = "post_platform_plot.jpeg")








    #r GRAPH 2 - post platform by income #


#make a condensed income variable
sis$income2 <- NULL

sis$income2[sis$q82 == 1] <- "Less than $10k"
sis$income2[sis$q82 == 2] <- "$10k - $50k"
sis$income2[sis$q82 == 3] <- "$10k - $50k"
sis$income2[sis$q82 == 4 | sis$q82 == 5] <- "$10k - $50k"
sis$income2[sis$q82 == 6 | sis$q82 == 7] <- "$50k - $100k"
sis$income2[sis$q82 == 8 | sis$q82 == 9 | sis$q82 == 10] <- "$50k - $100k"
sis$income2[sis$q82 >= 11] <- "More than $100k"

table(sis$income2)

sis$income2 <- as.factor(sis$income2)

sis$income2 <- ordered(sis$income2, levels = c("Less than $10k",  "$10k - $50k", "$50k - $100k", "More than $100k"))


inc_post_platform <- NULL
inc_post_platform<- sis %>%
  dplyr::select(starts_with("post_"), income2) %>%
  filter(post_sm != "Do Not Post") %>%
  group_by(income2) %>%
  dplyr::summarise(post_fb = mean(post_fb == 1, na.rm=T),
                   post_twitter = mean(post_twitter == 1, na.rm=T),
                   post_ig = mean(post_ig == 1, na.rm =T),
                   post_tiktok = mean(post_tiktok == 1, na.rm=T),
                   post_snap = mean(post_snap == 1, na.rm=T),
                   post_medium = mean(post_medium == 1, na.rm=T),
                   post_other = mean(post_other == 1, na.rm=T)) %>%
  gather(q,r,2:8) %>%
  mutate(r = round(r, digits=2))


inc_post_platform


inc_post_platform$q[inc_post_platform$q == "post_fb"] <- "Facebook"
inc_post_platform$q[inc_post_platform$q == "post_twitter"] <- "Twitter"
inc_post_platform$q[inc_post_platform$q == "post_ig"] <- "Instagram"
inc_post_platform$q[inc_post_platform$q == "post_tiktok"] <- "Tik Tok"
inc_post_platform$q[inc_post_platform$q == "post_snap"] <- "Snapchat"
inc_post_platform$q[inc_post_platform$q == "post_medium"] <- "Medium"
inc_post_platform$q[inc_post_platform$q == "post_other"] <- "Another Platform"

#define color palette

bhm1 <- c("#07060d", "#990000",
          "#ffe430", "#00bb50")
# position=position_dodge()

inc_post_platform_plot <- inc_post_platform %>%
  ggplot(aes(fill = income2, x=reorder(q,r),r)) +
  geom_bar(stat='identity',position=position_dodge(width =0.89)) +
  scale_y_continuous(labels = scales::percent) +
  theme(legend.position="bottom") +
 # coord_flip() +
 theme_ipsum() +  scale_fill_manual(values = bhm1) +
   theme(legend.position = "bottom") + guides(fill = guide_legend(nrow = 1)) +
  labs(x= "  ", y = "   ", title = "Black women's social media platform engagement by income levels", caption = "Black Women in Politics Survey (n=613)\n April 2022", fill = "")  + geom_text(aes(x = q, y = r, label =sprintf("%0.0f%%", r*100)), size = 2.5,  position=position_dodge(width =0.89), colour = "White", vjust = 1.3)

inc_post_platform_plot

ggsave(inc_post_platform_plot, width =9, height = 7, filename = "[GRAPH 2 revised]inc_post_platform_plot.jpeg")



    #r plot platform engagement by age#

age_post_platform<- sis %>%
  dplyr::select(starts_with("post_"), generation) %>%
  filter(post_sm != "Do Not Post") %>%
  filter(generation != "Post War") %>%
  group_by(generation) %>%
  dplyr::summarise(post_fb = mean(post_fb == 1, na.rm=T),
                   post_twitter = mean(post_twitter == 1, na.rm=T),
                   post_ig = mean(post_ig == 1, na.rm =T),
                   post_tiktok = mean(post_tiktok == 1, na.rm=T),
                   post_snap = mean(post_snap == 1, na.rm=T),
                   post_medium = mean(post_medium == 1, na.rm=T),
                   post_other = mean(post_other == 1, na.rm=T)) %>%
  gather(q,r,2:8) %>%
  mutate(r = round(r, digits=2)) %>% print(n=40)

#filter our older generation since few cases
table(sis$generation, sis$post_sm)
age_post_platform %>%
  filter(generation == "Post War")

#recode
age_post_platform$q[age_post_platform$q == "post_fb"] <- "Facebook"
age_post_platform$q[age_post_platform$q == "post_twitter"] <- "Twitter"
age_post_platform$q[age_post_platform$q == "post_ig"] <- "Instagram"
age_post_platform$q[age_post_platform$q == "post_tiktok"] <- "Tik Tok"
age_post_platform$q[age_post_platform$q == "post_snap"] <- "Snapchat"
age_post_platform$q[age_post_platform$q == "post_medium"] <- "Medium"
age_post_platform$q[age_post_platform$q == "post_other"] <- "Another Platform"

age_post_platform_plot <- age_post_platform %>%
  ggplot(aes(fill = generation, x=reorder(q,r),r)) +
  geom_bar(stat='identity',position=position_dodge(width =0.89)) +
  scale_y_continuous(labels = scales::percent) +
  theme(legend.position="bottom") +
 # coord_flip() +
 theme_ipsum() +
   theme(legend.position = "bottom") + guides(fill = guide_legend(nrow = 1)) +
  labs(x= "  ", y = "   ", title = "Black Women's Social Media  Platform Engagement by Generations", caption = "Black Women in Politics Survey (n=613)\n April 2022", fill = "")  + geom_text(aes(x = q, y = r, label =sprintf("%0.0f%%", r*100)), size = 2.5,  position=position_dodge(width =0.89), colour = "White", vjust = 2)

age_post_platform_plot

ggsave(age_post_platform_plot, width =9, height = 7, filename = "age_post_platform_plot.jpeg")



    #r platform engagement by edu#

edu_post_platform<- sis %>%
  dplyr::select(starts_with("post_"), education) %>%
  filter(post_sm != "Do Not Post") %>%
 # filter(generation != "Post War") %>%
  group_by(education) %>%
  dplyr::summarise(post_fb = mean(post_fb == 1, na.rm=T),
                   post_twitter = mean(post_twitter == 1, na.rm=T),
                   post_ig = mean(post_ig == 1, na.rm =T),
                   post_tiktok = mean(post_tiktok == 1, na.rm=T),
                   post_snap = mean(post_snap == 1, na.rm=T),
                   post_medium = mean(post_medium == 1, na.rm=T),
                   post_other = mean(post_other == 1, na.rm=T)) %>%
  gather(q,r,2:8) %>%
  mutate(r = round(r, digits=2)) %>% print(n=40)

table(sis$education, sis$post_sm)


edu_post_platform_plot <- edu_post_platform %>%
  ggplot(aes(fill = education, x=reorder(q,r),r)) +
  geom_bar(stat='identity',position=position_dodge(width =0.89)) +
  scale_y_continuous(labels = scales::percent) +
  theme(legend.position="bottom") +
 # coord_flip() +
 theme_ipsum() +
   theme(legend.position = "bottom") + guides(fill = guide_legend(nrow = 2)) +
  labs(x= "  ", y = "   ", title = "Black Women's Social Media  Platform Engagement by Education Level", caption = "Black Women in Politics Survey (n=613)\n April 2022", fill = "")  + geom_text(aes(x = q, y = r, label =sprintf("%0.0f%%", r*100)), size = 2.5,  position=position_dodge(width =0.89), colour = "White", vjust = 2)

edu_post_platform_plot

ggsave(edu_post_platform_plot, width =9, height = 7, filename = "edu_post_platform_plot.jpeg")



    #r black women engaged in political organizations#
# RENAME ITEMS
table(sis$q25_1)

sis$org_sorority <- ifelse(!is.na(sis$q25_1),1,0)
sis$org_fraternity <-ifelse(!is.na(sis$q25_2),1, 0)
sis$org_links <- ifelse(!is.na(sis$q25_3), 1, 0)
sis$org_pta <-ifelse(!is.na(sis$q25_4 ),1, 0)
sis$org_jja <-ifelse(!is.na(sis$q25_5 ),1, 0)
sis$org_oes <- ifelse(!is.na(sis$q25_6), 1, 0)
sis$org_religious <-ifelse(!is.na(sis$q25_7),1, 0)
sis$org_local_rep <- ifelse(!is.na(sis$q25_8), 1, 0)
sis$org_local_dem <- ifelse(!is.na(sis$q25_9), 1, 0)
sis$org_natl_rep <- ifelse(!is.na(sis$q25_10), 1, 0)
sis$org_natl_dem <- ifelse(!is.na(sis$q25_11), 1, 0)
sis$org_other <- ifelse(!is.na(sis$q25_12), 1, 0)
sis$org_none <- ifelse(!is.na(sis$q25_13), 1, 0)

table(sis$q137) # some are gibberish, some can be recoded!
table(sis$post_other)

org_involvement<- sis %>%
  dplyr::select(starts_with("org_")) %>%
  #filter(post_sm != "Do Not Post") %>%
  #group_by(education) %>%
  dplyr::summarise(org_none = mean(org_none == 1, na.rm=T),
                   org_other = mean(org_other == 1, na.rm=T),
                   org_natl_dem = mean(org_natl_dem == 1, na.rm =T),
                   org_natl_rep = mean(org_natl_rep == 1, na.rm=T),
                   org_local_dem = mean(org_local_dem == 1, na.rm=T),
                   org_local_rep = mean(org_local_rep == 1, na.rm=T),
                   org_religious = mean(org_religious == 1, na.rm=T),
                   org_oes = mean(org_oes == 1, na.rm=T),
                   org_jja = mean(org_jja == 1, na.rm=T),
                   org_pta = mean(org_pta == 1, na.rm=T),
                   org_links = mean(org_links == 1, na.rm=T),
                   org_fraternity = mean(org_fraternity == 1, na.rm=T),
                   org_sorority = mean(org_sorority == 1, na.rm=T)
                   ) %>%
  gather(q,r,1:13) %>%
  mutate(r = round(r, digits=2)) #%>% print(n=40)


org_plot <- org_involvement %>%
    ggplot(aes(x=reorder(q,r),r))  +
  geom_bar(stat='identity',position=position_dodge()) +
  scale_y_continuous(labels = scales::percent) +
  theme(legend.position="bottom") +
  coord_flip() +
theme_ipsum() +
  labs(x= "  ", y = "   ", title = "Black Women's Organizational Involvement", caption = "Black Women in Politics Survey (N= 2,284)\n April 2022", fill = "") +
  geom_text(aes(x = q, y = round(r, digits = 2), label =sprintf("%0.0f%%", r*100)), size = 2.5,  position=position_dodge(width =0.89), colour = "White", hjust = 1)

org_plot

ggsave(org_plot, width =7, height = 9, filename = "org_plot.jpeg")



    #r are offline bw engaged #
#recode new variable
sis$freq_post[sis$post_sm == "Do Not Post"] <- "No Political Posts"
sis$freq_post[sis$post_sm != "Do Not Post"] <- "Political Posts"

offline_org_involvement<- sis %>%
  dplyr::select(starts_with("org_"), freq_post) %>%
  #filter(post_sm != "Do Not Post") %>%
  group_by(freq_post) %>%
  dplyr::summarise(org_none = mean(org_none == 1, na.rm=T),
                   org_other = mean(org_other == 1, na.rm=T),
                   org_natl_dem = mean(org_natl_dem == 1, na.rm =T),
                   org_natl_rep = mean(org_natl_rep == 1, na.rm=T),
                   org_local_dem = mean(org_local_dem == 1, na.rm=T),
                   org_local_rep = mean(org_local_rep == 1, na.rm=T),
                   org_religious = mean(org_religious == 1, na.rm=T),
                   org_oes = mean(org_oes == 1, na.rm=T),
                   org_jja = mean(org_jja == 1, na.rm=T),
                   org_pta = mean(org_pta == 1, na.rm=T),
                   org_links = mean(org_links == 1, na.rm=T),
                   org_fraternity = mean(org_fraternity == 1, na.rm=T),
                   org_sorority = mean(org_sorority == 1, na.rm=T)
                   ) %>%
  gather(q,r,2:13) %>%
  mutate(r = round(r, digits=2)) #%>% print(n=40)

offline_org_involvement

offline_org_involvement_plot <- offline_org_involvement %>%
  filter(freq_post)
    ggplot(aes(x=reorder(q,r),r), fill = freq_post)  +
  geom_bar(stat='identity',position=position_dodge()) +
  scale_y_continuous(labels = scales::percent) +
  theme(legend.position="bottom") +
  coord_flip() +
  facet_grid(~freq_post) +
theme_ipsum() +
  labs(x= "  ", y = "   ", title = "Black Women's Organizational Involvement and Media Posts", caption = "Black Women in Politics Survey (N= 2,284)\n April 2022", fill = "") +
  geom_text(aes(x = q, y = round(r, digits = 2), label =sprintf("%0.0f%%", r*100)), size = 2.5,  position=position_dodge(width =0.89), colour = "White", hjust = 1)

offline_org_involvement_plot


ggsave(offline_org_involvement_plot, width =7, height = 9, filename = "offline_org_involvement_plot.jpeg")






